SPICE-backed adapter for Angelus.Ephemeris.
Summary
Functions
Returns SPICE-backed state data for a public ephemeris body atom.
Converts UTC datetime to SPICE ephemeris time through Angelus.Spice.
Functions
Returns SPICE-backed state data for a public ephemeris body atom.
@spec utc_to_et(DateTime.t()) :: {:ok, float()} | {:error, term()}
Converts UTC datetime to SPICE ephemeris time through Angelus.Spice.